@@ -4,6 +4,7 @@
 #  variables are expanded. 
 #  
 #  all  : return all columns or only the categorical variables.
+#  names: names of cols to expand as dummy variables.
 #
 #  TODO:
 #   - matrix?
@@ -11,19 +12,31 @@
 #
 # -----------------------------------------------------------------------------
 
-dummy.data.frame <- function( data, all=TRUE, dummy.classes=getOption("dummy.classes"), ... ) {
+dummy.data.frame <- function( data, names=NULL, omit.constants = TRUE, dummy.classes=getOption("dummy.classes"), all=TRUE, ... ) {
 
   # Initialize the data.frame
-    df<-data.frame( row.names=row.names(data) )
+    df<-data.frame( row.names=row.names(data) )     
     new.attr <- list()  # Track location of dummy variables
 
     for( nm in names(data) ) {
       
+# cat( nm )
       old.attr <- attr(df,'dummies')
-      if( class(data[,nm]) %in% dummy.classes ) {
+      
+      if(
+        nm %in% names || 
+        ( is.null(names) && ( dummy.classes == "ALL" || class(data[,nm]) %in% dummy.classes ) )
+      ) {
 
         dummies <- dummy( nm, data, ... )
-        new.attr[[nm]] <- (ncol(df)+1):( ncol(df)+ncol(dummies) ) 
+
+        # OMIT CONSTANT COLUMNS:
+        #  Variables that are constant will return a matrix with one column
+        if( ncol(dummies) == 1  & omit.constants ) {
+          dummies <- matrix( nrow=nrow(data), ncol=0 ) 
+        }
+            
+        if( ncol(dummies)>0 ) new.attr[[nm]] <- (ncol(df)+1):( ncol(df)+ncol(dummies) ) 
 
       } else {
         if( ! all ) next()
@@ -31,6 +44,7 @@ dummy.data.frame <- function( data, all=TRUE, dummy.classes=getOption("dummy.cla
       }
 
       df <- cbind(df, dummies)
+
     }
 
     attr( df, 'dummies' ) <- new.attr
